%global appliance_root /opt/rh/cfme-appliance
%global app_root /var/www/miq/vmdb

Name:     cfme-appliance
Version:  5.5.3.4
Release:  1%{?dist}
Summary:  CloudForms Management Engine appliance configuration

Group:    Applications/Internet
License:  Unknown
URL:      https://github.com/ManageIQ/manageiq-appliance

Source0:  %{name}-%{version}.tar.gz

Requires: cfme = %{version}

Requires: httpd

Requires: chrony

Requires: cloud-init

# External Authentication
Requires: sssd >= 1.11.6
Requires: sssd-dbus >= 1.11.6

# External Authentication - IPA
Requires: c-ares >= 1.7.0
Requires: ipa-admintools >= 3.0.0
Requires: ipa-client >= 3.0.0
Requires: mod_intercept_form_submit >= 0.9.7
Requires: mod_auth_kerb >= 5.4
Requires: mod_authnz_pam >= 0.9.2
Requires: mod_lookup_identity >= 0.9.2
Requires: mod_ssl

# External Authentication - Active Directory
Requires: adcli
Requires: oddjob
Requires: oddjob-mkhomedir
Requires: realmd
Requires: samba-common

# External Authentication - LDAP
Requires: openldap-clients

# SCAP
Requires: openscap
Requires: scap-security-guide

# Tools
Requires: vim-enhanced

%description
CloudForms Management Engine Appliance

%prep
%setup -q

%pretrans -p <lua>
if posix.access('/bin/evmserver.sh', 'x') then
  local pid = posix.fork ()
  if ( pid == -1 ) then
    print ("The fork failed.")
  elseif ( pid == 0 ) then
    posix.exec('/bin/evmserver.sh', 'update_stop')
  else
    posix.wait(pid)
  end
end

%posttrans -p <lua>
if posix.access('/bin/evmserver.sh', 'x') then
  local pid = posix.fork ()
  if ( pid == -1 ) then
    print ("The fork failed.")
  elseif ( pid == 0 ) then
    posix.exec('/bin/evmserver.sh', 'update_start')
  else
    posix.wait(pid)
  end
end

%install

%{__mkdir} -p %{buildroot}%{appliance_root}
%{__cp} -r * %{buildroot}%{appliance_root}
%{__mkdir} -p %{buildroot}/etc/httpd/conf.d
%{__mkdir} -p %{buildroot}%{app_root}/log/apache

#symlink some executables
%{__mkdir} -p %{buildroot}/%{_bindir}
pushd ./LINK/usr/bin
  for filename in `ls`; do
    ln -s %{appliance_root}/LINK/usr/bin/$filename %{buildroot}/%{_bindir}/$filename
  done
popd

#symlink some configuration files
pushd ./LINK/etc
  for dirname in `ls`; do
    pushd ./$dirname
      %{__mkdir} -p %{buildroot}/%{_sysconfdir}/$dirname
      for filename in `ls`; do
        ln -s %{appliance_root}/LINK/etc/$dirname/$filename %{buildroot}/%{_sysconfdir}/$dirname/$filename
      done
    popd
  done
popd

%{__mkdir} -p %{buildroot}/root
pushd ./LINK/root
  ln -s %{appliance_root}/LINK/root/.bowerrc %{buildroot}/root/.bowerrc
popd

pushd ./LINK
  ln -s %{appliance_root}/LINK/.toprc %{buildroot}/.toprc
popd

#symlink license file for prince PDF
%{__mkdir} -p %{buildroot}%{_prefix}/lib/prince/license
ln -s %{appliance_root}/LINK/usr/lib/prince/license/license.dat %{buildroot}%{_prefix}/lib/prince/license/license.dat

#copy all files/directories below COPY
%{__cp} -r ./COPY/* %{buildroot}/

%post

#Ensure pre-5.4 external auth configuration is honored with the new 5.4 layout.
httpd_conf_dir=%{_sysconfdir}/httpd/conf.d
pre_http_external_auth=${httpd_conf_dir}/cfme-external-auth
http_external_auth=${httpd_conf_dir}/cfme-external-auth.conf
http_remote_user_template=%{app_root}/system/TEMPLATE/etc/httpd/conf.d/cfme-remote-user.conf

if [ ! -f ${http_external_auth} -a -f %{_sysconfdir}/sssd/sssd.conf -a -f ${http_remote_user_template} ]
then
  if [ -f ${pre_http_external_auth} ]
  then
    %{__cp} ${pre_http_external_auth} ${http_external_auth}
  fi
  %{__cp} ${http_remote_user_template} ${httpd_conf_dir}/cfme-remote-user.conf
fi

#motd is owned by system
%{__cp} -f %{_sysconfdir}/motd.manageiq %{_sysconfdir}/motd

%postun

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
/.toprc
/root/.bowerrc
%{appliance_root}
%{app_root}/log/apache
%{_bindir}/appliance_console
%{_bindir}/appliance_console_cli
%{_bindir}/cloud_ds_check.sh
%{_bindir}/evm*
%{_bindir}/fix_auth
%{_bindir}/miq*
%{_localstatedir}/www/html/proxy_pages/invalid_sso_credentials.js
%{_prefix}/lib/prince/license/license.dat
%{_prefix}/lib/systemd/system/cloud-ds-check.service
%{_prefix}/lib/systemd/system/evm*
%{_prefix}/lib/systemd/system/miq*
%{_sbindir}/ifup-local
%{_sysconfdir}/cloud/cloud.cfg.d/10_miq_logging.cfg
%{_sysconfdir}/cloud/cloud.cfg.d/miq_cloud.cfg
%{_sysconfdir}/cron.hourly/miqtimestamp-hourly.cron
%{_sysconfdir}/default/evm*
%{_sysconfdir}/httpd/conf.d/cfme-*
%{_sysconfdir}/issue.template
%{_sysconfdir}/logrotate.d/miq_logs.conf
%{_sysconfdir}/motd.manageiq
%{_sysconfdir}/profile.d/evm.sh

%changelog
* Thu Apr 07 2016 John Prause <jprause@redhat.com> - 5.5.3.4-1
- Building 5.5.3.4-1

* Tue Apr 05 2016 John Prause <jprause@redhat.com> - 5.5.3.3-1
- Building 5.5.3.3-1

* Fri Mar 18 2016 Satoe Imaishi <simaishi@redhat.com> - 5.5.3.2-1
- Building 5.5.3.2-1

* Thu Mar 17 2016 Satoe Imaishi <simaishi@redhat.com> - 5.5.3.1-1
- Building 5.5.3.1-1

* Tue Mar 15 2016 Satoe Imaishi <simaishi@redhat.com> - 5.5.3.0-1
- Building 5.5.3.0-1

* Wed Jan 27 2016 John Prause <jprause@redhat.com> - 5.5.2.4-1
- Building 5.5.2.4-1 - needed to skip 5.5.2.3 build

* Thu Jan 21 2016 John Prause <jprause@redhat.com> - 5.5.2.2-1
- Building 5.5.2.2-1 

* Thu Jan 14 2016 John Prause <jprause@redhat.com> - 5.5.2.1-1
- Building 5.5.2.1-1 

* Wed Dec 23 2015 John Prause <jprause@redhat.com> - 5.5.2.0-3
- Building 5.5.2.0-3 removed extra character added by mistake

* Wed Dec 23 2015 John Prause <jprause@redhat.com> - 5.5.2.0-2
- Building 5.5.2.0-2 for Requires chrony addition

* Mon Dec 21 2015 John Prause <jprause@redhat.com> - 5.5.2.0-1
- Building 5.5.2.0-1

* Tue Dec 01 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.13
- Building 5.5.0.13

* Tue Nov 24 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.12-rc2.1
- Building 5.5.0.12 rc2.1

* Tue Nov 17 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.11-rc1.1
- Building 5.5.0.11 rc1.1

* Tue Nov 10 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.10-beta2.1.1
- Building 5.5.0.10 beta2.1.1

* Mon Nov 02 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.9-beta2.1
- Building 5.5.0.9 beta2.1

* Tue Oct 27 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.8-beta1.4.1
- Building 5.5.0.8 beta1.4.1

* Wed Oct 21 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.7-beta1.3.1
- Building 5.5.0.7 beta1.3.1

* Wed Oct 14 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.6-beta1.2.1
- Building 5.5.0.6 beta1.2.1

* Wed Oct 07 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.5-beta1.1.1
- Building 5.5.0.5 beta1.1.1

* Wed Oct 07 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.4-beta1.1
- Building 5.5.0.4 beta1.1

* Tue Sep 29 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.3-alpha1.2.1
- Building 5.5.0.3 alpha1.2.1

* Wed Sep 23 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.2-alpha1.1.1
- Building 5.5.0.2 alpha1.1.1

* Tue Sep 15 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.1-alpha1.2
- Building 5.5.0.1 alpha1.2 without cloud-init

* Tue Sep 15 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.1-alpha1.1
- Building 5.5.0.1 alpha1

* Fri Sep 11 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.0-alpha.2
- Initial Build
